@@ -13,10 +13,18 @@ def kb_central_poller(current_track_id):
     while True:
         print()
         print('- - - - - - - - - - - - - - - - - - - - -')
-        print(f'{helper.getDateString()} POLLER CENTRAL...')
+        print('Henter events fra kukglebane centralen...')
+        print()
 
         count = kb_central.get_number_of_events_for_track(current_track_id)
-        microbit.send_message(f'EVENT-TRACKS:{current_track_id}:{count}')
+        print()
+        print(f'Antal events modtaget i alt: {count}')
+        print()
+
+        # Do not send events automatically for now
+        # We go for a "pure" polling solution
+
+        # microbit.send_message(f'EVENT-TRACKS:{current_track_id}:{count}')
 
         interval = kb_config.poll_interval_in_seconds
         text_interval = f'{interval} sekunder' if interval <=60 else f'ca. {"%.0f" % (interval / 60)} minutter'
